==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/bookmarks.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>BookMarks</name>
    <message>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <source>Edit bookmarks</source>
        <translation>Lesezeichen bearbeiten</translation>
    </message>
    <message>
        <source>Allows to create bookmarks at the jabber conference and web pages</source>
        <translation>Erlaubt das Erstellen von Lesezeichen bei den Jabber Konferezen- und Webseiten</translation>
    </message>
    <message>
        <source>Append to bookmarks</source>
        <translation>Zu Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <source>Disable autojoin to conferences</source>
        <translation></translation>
    </message>
    <message>
        <source>Edit bookmark</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>EditBookmarkDialog</name>
    <message>
        <source>Bookmark is not valid</source>
        <translation>Lesezeichen ist ungültig</translation>
    </message>
    <message>
        <source>Field &apos;Name&apos; should not be empty</source>
        <translation>Feld &apos;Name&apos; dürfen nicht leer sein</translation>
    </message>
    <message>
        <source>In URL bookmark field &apos;URL&apos; should not be empty</source>
        <translation>Das URL-Lesezeichen Feld &apos;Adresse&apos; darf nicht leer sein</translation>
    </message>
    <message>
        <source>In conference bookmark field &apos;Room&apos; should not be empty</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>EditBookmarkDialogClass</name>
    <message>
        <source>Edit bookmark</source>
        <translation>Lesezeichen bearbeiten</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Conference bookmark</source>
        <translation>Konferenz Lesezeichen</translation>
    </message>
    <message>
        <source>Room:</source>
        <translation>Raum:</translation>
    </message>
    <message>
        <source>Nick:</source>
        <translation>Spitzname:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Auto join</source>
        <translation>Automatisch beitreten</translation>
    </message>
    <message>
        <source>URL bookmark</source>
        <translation>URL Lesezeichen</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <source>Bookmarks not saved</source>
        <translation>Lesezeichen nicht gespeichert</translation>
    </message>
    <message>
        <source>Cant save bookmarks to server</source>
        <translation>Kann Lesezeichen nicht auf Server speichern</translation>
    </message>
    <message>
        <source>Cant save bookmarks to server. %1</source>
        <translation>Kann Lesezeichen nicht auf Server speichern. %1</translation>
    </message>
    <message>
        <source>Edit bookmarks - %1</source>
        <translation>Lesezeichen bearbeiten - %1</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialogClass</name>
    <message>
        <source>Edit bookmarks</source>
        <translation>Lesezeichen bearbeiten</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>JID/URL</source>
        <translation>JID/URL</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Spitzname</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Runter</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/bookmarks.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>BookMarks</name>
    <message>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <source>Edit bookmarks</source>
        <translation>Lesezeichen bearbeiten</translation>
    </message>
    <message>
        <source>Allows to create bookmarks at the jabber conference and web pages</source>
        <translation>Erlaubt das Erstellen von Lesezeichen für Jabber Konferenzen und Webseiten</translation>
    </message>
    <message>
        <source>Append to bookmarks</source>
        <translation>Zu Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <source>Disable autojoin to conferences</source>
        <translation>Sperre das automatische Verbinden zu Konferenzen</translation>
    </message>
    <message>
        <source>Edit bookmark</source>
        <translation>Lesezeichen bearbeiten</translation>
    </message>
    <message>
        <source>Automatically show window of conferences connected at startup</source>
        <translation>Automatisch Fenster für beim Startup verbundene Konferenzen zeigen</translation>
    </message>
</context>
<context>
    <name>EditBookmarkDialog</name>
    <message>
        <source>Bookmark is not valid</source>
        <translation>Lesezeichen ist ungültig</translation>
    </message>
    <message>
        <source>Field &apos;Name&apos; should not be empty</source>
        <translation>Feld &apos;Name&apos; darf nicht leer sein</translation>
    </message>
    <message>
        <source>In URL bookmark field &apos;URL&apos; should not be empty</source>
        <translation>Das URL-Lesezeichen Feld &apos;Adresse&apos; darf nicht leer sein</translation>
    </message>
    <message>
        <source>In conference bookmark field &apos;Room&apos; should not be empty</source>
        <translation>Das Konferenz-Lesezeichen Feld &apos;Raum&apos; darf nicht leer sein</translation>
    </message>
</context>
<context>
    <name>EditBookmarkDialogClass</name>
    <message>
        <source>Edit bookmark</source>
        <translation>Lesezeichen bearbeiten</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Conference bookmark</source>
        <translation>Konferenz Lesezeichen</translation>
    </message>
    <message>
        <source>Room:</source>
        <translation>Raum:</translation>
    </message>
    <message>
        <source>Nick:</source>
        <translation>Spitzname:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Auto join</source>
        <translation>Automatisch beitreten</translation>
    </message>
    <message>
        <source>URL bookmark</source>
        <translation>URL Lesezeichen</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <source>Bookmarks not saved</source>
        <translation>Lesezeichen nicht gespeichert</translation>
    </message>
    <message>
        <source>Cant save bookmarks to server</source>
        <translation>Kann Lesezeichen nicht auf Server speichern</translation>
    </message>
    <message>
        <source>Cant save bookmarks to server. %1</source>
        <translation>Kann Lesezeichen nicht auf Server speichern. %1</translation>
    </message>
    <message>
        <source>Edit bookmarks - %1</source>
        <translation>Lesezeichen bearbeiten - %1</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialogClass</name>
    <message>
        <source>Edit bookmarks</source>
        <translation>Lesezeichen bearbeiten</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>JID/URL</source>
        <translation>JID/URL</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Spitzname</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Runter</translation>
    </message>
</context>
</TS>
